"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    user_id: str,
    first_name: str = None,
    last_name: str = None,
    email: str = None,
    client_request_token: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a user.

    Args:
        user_id(str): The ARN for the user.
        first_name(str, optional): The first name for the user. Defaults to None.
        last_name(str, optional): The last name for the user. Defaults to None.
        email(str, optional): The email address for the user. Defaults to None.
        client_request_token(str, optional): A unique, user-specified identifier for this request that ensures idempotency. . Defaults to None.
        tags(List, optional): The tags for the user. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.user.create(ctx, user_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.user.create user_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="create_user",
        op_kwargs={
            "UserId": user_id,
            "FirstName": first_name,
            "LastName": last_name,
            "Email": email,
            "ClientRequestToken": client_request_token,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, enrollment_id: str, user_arn: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a specified user by user ARN and enrollment ARN.

    Args:
        user_arn(str, optional): The ARN of the user to delete in the organization. Required. Defaults to None.
        enrollment_id(str): The ARN of the user's enrollment in the organization. Required.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.user.delete(ctx, enrollment_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.user.delete enrollment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="delete_user",
        op_kwargs={"UserArn": user_arn, "EnrollmentId": enrollment_id},
    )


async def search(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    filters: List = None,
    sort_criteria: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Searches users and lists the ones that meet a set of filter and sort criteria.

    Args:
        next_token(str, optional): An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response includes only results beyond the token, up to the value specified by MaxResults. Required. Defaults to None.
        max_results(int, optional): The maximum number of results to include in the response. If more results exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved. Required. Defaults to None.
        filters(List, optional): The filters to use for listing a specific set of users. Required. Supported filter keys are UserId, FirstName, LastName, Email, and EnrollmentStatus. Defaults to None.
        sort_criteria(List, optional): The sort order to use in listing the filtered set of users. Required. Supported sort keys are UserId, FirstName, LastName, Email, and EnrollmentStatus. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.user.search(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.user.search
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="search_users",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "Filters": filters,
            "SortCriteria": sort_criteria,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    job_ids: List = None,
    filters: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes recommendation export jobs created in the last seven days. Use the ExportAutoScalingGroupRecommendations or ExportEC2InstanceRecommendations actions to request an export of your recommendations. Then use the DescribeRecommendationExportJobs action to view your export jobs.

    Args:
        job_ids(List, optional): The identification numbers of the export jobs to return. An export job ID is returned when you create an export using the ExportAutoScalingGroupRecommendations or ExportEC2InstanceRecommendations actions. All export jobs created in the last seven days are returned if this parameter is omitted. Defaults to None.
        filters(List, optional): An array of objects that describe a filter to return a more specific list of export jobs. Defaults to None.
        next_token(str, optional): The token to advance to the next page of export jobs. Defaults to None.
        max_results(int, optional): The maximum number of export jobs to return with a single request. To retrieve the remaining results, make another request with the returned NextToken value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.compute_optimizer.recommendation.export_job.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.compute_optimizer.recommendation.export_job.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="compute-optimizer",
        operation="describe_recommendation_export_jobs",
        op_kwargs={
            "jobIds": job_ids,
            "filters": filters,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, deployment_id: str = None, target_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

     Returns information about a deployment target.

    Args:
        deployment_id(str, optional):  The unique ID of a deployment. . Defaults to None.
        target_id(str, optional):  The unique ID of a deployment target. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.deployment.target.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.deployment.target.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="get_deployment_target",
        op_kwargs={"deploymentId": deployment_id, "targetId": target_id},
    )


async def list_all(
    hub,
    ctx,
    deployment_id: str = None,
    next_token: str = None,
    target_filters: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Returns an array of target IDs that are associated a deployment.

    Args:
        deployment_id(str, optional):  The unique ID of a deployment. . Defaults to None.
        next_token(str, optional):  A token identifier returned from the previous ListDeploymentTargets call. It can be used to return the next set of deployment targets in the list. . Defaults to None.
        target_filters(Dict, optional):  A key used to filter the returned targets. The two valid values are:    TargetStatus - A TargetStatus filter string can be Failed, InProgress, Pending, Ready, Skipped, Succeeded, or Unknown.     ServerInstanceLabel - A ServerInstanceLabel filter string can be Blue or Green.   . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.deployment.target.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.deployment.target.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="list_deployment_targets",
        op_kwargs={
            "deploymentId": deployment_id,
            "nextToken": next_token,
            "targetFilters": target_filters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, start_time: str = None, end_time: str = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns all public keys whose private keys were used to sign the digest files within the specified time range. The public key is needed to validate digest files that were signed with its corresponding private key.  CloudTrail uses different private/public key pairs per region. Each digest file is signed with a private key unique to its region. Therefore, when you validate a digest file from a particular region, you must look in the same region for its corresponding public key.

    Args:
        start_time(str, optional): Optionally specifies, in UTC, the start of the time range to look up public keys for CloudTrail digest files. If not specified, the current time is used, and the current public key is returned. Defaults to None.
        end_time(str, optional): Optionally specifies, in UTC, the end of the time range to look up public keys for CloudTrail digest files. If not specified, the current time is used. Defaults to None.
        next_token(str, optional): Reserved for future use. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudtrail.public_key.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudtrail.public_key.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudtrail",
        operation="list_public_keys",
        op_kwargs={
            "StartTime": start_time,
            "EndTime": end_time,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def update(
    hub,
    ctx,
    domain: str,
    repository: str,
    format_: str,
    package: str,
    versions: List,
    target_status: str,
    domain_owner: str = None,
    namespace: str = None,
    version_revisions: Dict = None,
    expected_status: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Updates the status of one or more versions of a package.

    Args:
        domain(str):  The name of the domain that contains the repository that contains the package versions with a status to be updated. .
        domain_owner(str, optional):  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. . Defaults to None.
        repository(str):  The repository that contains the package versions with the status you want to update. .
        format_(str):  A format that specifies the type of the package with the statuses to update. The valid values are:     npm     pypi     maven   .
        namespace(str, optional):  The namespace of the package. The package component that specifies its namespace depends on its type. For example:     The namespace of a Maven package is its groupId.     The namespace of an npm package is its scope.     A Python package does not contain a corresponding component, so Python packages do not have a namespace.   . Defaults to None.
        package(str):  The name of the package with the version statuses to update. .
        versions(List):  An array of strings that specify the versions of the package with the statuses to update. .
        version_revisions(Dict, optional):  A map of package versions and package version revisions. The map key is the package version (for example, 3.5.2), and the map value is the package version revision. . Defaults to None.
        expected_status(str, optional):  The package version’s expected status before it is updated. If expectedStatus is provided, the package version's status is updated only if its status at the time UpdatePackageVersionsStatus is called matches expectedStatus. . Defaults to None.
        target_status(str):  The status you want to change the package version status to. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeartifact.package.version.status.update(
                ctx,
                domain=value,
                repository=value,
                format_=value,
                package=value,
                versions=value,
                target_status=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeartifact.package.version.status.update domain=value, repository=value, format_=value, package=value, versions=value, target_status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeartifact",
        operation="update_package_versions_status",
        op_kwargs={
            "domain": domain,
            "domainOwner": domain_owner,
            "repository": repository,
            "format": format_,
            "namespace": namespace,
            "package": package,
            "versions": versions,
            "versionRevisions": version_revisions,
            "expectedStatus": expected_status,
            "targetStatus": target_status,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, environment_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an Cloud9 development environment. If an Amazon EC2 instance is connected to the environment, also terminates the instance.

    Args:
        environment_id(str): The ID of the environment to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloud9.environment.init.delete(ctx, environment_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloud9.environment.init.delete environment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloud9",
        operation="delete_environment",
        op_kwargs={"environmentId": environment_id},
    )


async def describe_all(hub, ctx, environment_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about Cloud9 development environments.

    Args:
        environment_ids(List): The IDs of individual environments to get information about.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloud9.environment.init.describe_all(ctx, environment_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloud9.environment.init.describe_all environment_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloud9",
        operation="describe_environments",
        op_kwargs={"environmentIds": environment_ids},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of Cloud9 development environment identifiers.

    Args:
        next_token(str, optional): During a previous call, if there are more than 25 items in the list, only the first 25 items are returned, along with a unique string called a next token. To get the next batch of items in the list, call this operation again, adding the next token to the call. To get all of the items in the list, keep calling this operation with each subsequent next token that is returned, until no more next tokens are returned. Defaults to None.
        max_results(int, optional): The maximum number of environments to get identifiers for. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloud9.environment.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloud9.environment.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloud9",
        operation="list_environments",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )


async def update(
    hub, ctx, environment_id: str, name: str = None, description: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Changes the settings of an existing Cloud9 development environment.

    Args:
        environment_id(str): The ID of the environment to change settings.
        name(str, optional): A replacement name for the environment. Defaults to None.
        description(str, optional): Any new or replacement description for the environment. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloud9.environment.init.update(ctx, environment_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloud9.environment.init.update environment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloud9",
        operation="update_environment",
        op_kwargs={
            "environmentId": environment_id,
            "name": name,
            "description": description,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(
    hub,
    ctx,
    workbook_id: str,
    table_id: str,
    row_ids: List,
    client_request_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     The BatchDeleteTableRows API allows you to delete one or more rows from a table in a workbook. You need to specify the ids of the rows that you want to delete from the table.

    Args:
        workbook_id(str): The ID of the workbook where the rows are being deleted.  If a workbook with the specified id could not be found, this API throws ResourceNotFoundException. .
        table_id(str): The ID of the table where the rows are being deleted.  If a table with the specified id could not be found, this API throws ResourceNotFoundException. .
        row_ids(List):  The list of row ids to delete from the table. You need to specify at least one row id in this list.   Note that if one of the row ids provided in the request does not exist in the table, then the request fails and no rows are deleted from the table. .
        client_request_token(str, optional):  The request token for performing the delete action. Request tokens help to identify duplicate requests. If a call times out or fails due to a transient error like a failed network connection, you can retry the call with the same request token. The service ensures that if the first call using that request token is successfully performed, the second call will not perform the action again.   Note that request tokens are valid only for a few minutes. You cannot use request tokens to dedupe requests spanning hours or days. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.honeycode.delete_table_row.batch(
                ctx, workbook_id=value, table_id=value, row_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.honeycode.delete_table_row.batch workbook_id=value, table_id=value, row_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="honeycode",
        operation="batch_delete_table_rows",
        op_kwargs={
            "workbookId": workbook_id,
            "tableId": table_id,
            "rowIds": row_ids,
            "clientRequestToken": client_request_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Returns the enrollment (opt in) status of an account to the AWS Compute Optimizer service. If the account is the management account of an organization, this action also confirms the enrollment status of member accounts within the organization.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.compute_optimizer.enrollment_status.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.compute_optimizer.enrollment_status.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="compute-optimizer",
        operation="get_enrollment_status",
        op_kwargs={},
    )


async def update(hub, ctx, status: str, include_member_accounts: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates the enrollment (opt in and opt out) status of an account to the AWS Compute Optimizer service. If the account is a management account of an organization, this action can also be used to enroll member accounts within the organization. You must have the appropriate permissions to opt in to Compute Optimizer, to view its recommendations, and to opt out. For more information, see Controlling access with AWS Identity and Access Management in the AWS Compute Optimizer User Guide. When you opt in, Compute Optimizer automatically creates a Service-Linked Role in your account to access its data. For more information, see Using Service-Linked Roles for AWS Compute Optimizer in the AWS Compute Optimizer User Guide.

    Args:
        status(str): The new enrollment status of the account. The following status options are available:    Active - Opts in your account to the Compute Optimizer service. Compute Optimizer begins analyzing the configuration and utilization metrics of your AWS resources after you opt in. For more information, see Metrics analyzed by AWS Compute Optimizer in the AWS Compute Optimizer User Guide.    Inactive - Opts out your account from the Compute Optimizer service. Your account's recommendations and related metrics data will be deleted from Compute Optimizer after you opt out.    The Pending and Failed options cannot be used to update the enrollment status of an account. They are returned in the response of a request to update the enrollment status of an account. .
        include_member_accounts(bool, optional): Indicates whether to enroll member accounts of the organization if the account is the management account of an organization. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.compute_optimizer.enrollment_status.update(ctx, status=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.compute_optimizer.enrollment_status.update status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="compute-optimizer",
        operation="update_enrollment_status",
        op_kwargs={"status": status, "includeMemberAccounts": include_member_accounts},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    engine: str = None,
    language_code: str = None,
    include_additional_language_codes: bool = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the list of voices that are available for use when requesting speech synthesis. Each voice speaks a specified language, is either male or female, and is identified by an ID, which is the ASCII version of the voice name.  When synthesizing speech ( SynthesizeSpeech ), you provide the voice ID for the voice you want from the list of voices returned by DescribeVoices. For example, you want your news reader application to read news in a specific language, but giving a user the option to choose the voice. Using the DescribeVoices operation you can provide the user with a list of available voices to select from.  You can optionally specify a language code to filter the available voices. For example, if you specify en-US, the operation returns a list of all available US English voices.  This operation requires permissions to perform the polly:DescribeVoices action.

    Args:
        engine(str, optional): Specifies the engine (standard or neural) used by Amazon Polly when processing input text for speech synthesis. . Defaults to None.
        language_code(str, optional):  The language identification tag (ISO 639 code for the language name-ISO 3166 country code) for filtering the list of voices returned. If you don't specify this optional parameter, all available voices are returned. . Defaults to None.
        include_additional_language_codes(bool, optional): Boolean value indicating whether to return any bilingual voices that use the specified language as an additional language. For instance, if you request all languages that use US English (es-US), and there is an Italian voice that speaks both Italian (it-IT) and US English, that voice will be included if you specify yes but not if you specify no. Defaults to None.
        next_token(str, optional): An opaque pagination token returned from the previous DescribeVoices operation. If present, this indicates where to continue the listing. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.polly.voice.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.polly.voice.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="polly",
        operation="describe_voices",
        op_kwargs={
            "Engine": engine,
            "LanguageCode": language_code,
            "IncludeAdditionalLanguageCodes": include_additional_language_codes,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    domain_id: str,
    user_profile_name: str,
    session_expiration_duration_in_seconds: int = None,
    expires_in_seconds: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a URL for a specified UserProfile in a Domain. When accessed in a web browser, the user will be automatically signed in to Amazon SageMaker Studio, and granted access to all of the Apps and files associated with the Domain's Amazon Elastic File System (EFS) volume. This operation can only be called when the authentication mode equals IAM.  The IAM role or user used to call this API defines the permissions to access the app. Once the presigned URL is created, no additional permission is required to access this URL. IAM authorization policies for this API are also enforced for every HTTP request and WebSocket frame that attempts to connect to the app. You can restrict access to this API and to the URL that it returns to a list of IP addresses, Amazon VPCs or Amazon VPC Endpoints that you specify. For more information, see Connect to SageMaker Studio Through an Interface VPC Endpoint .  The URL that you get from a call to CreatePresignedDomainUrl has a default timeout of 5 minutes. You can configure this value using ExpiresInSeconds. If you try to use the URL after the timeout limit expires, you are directed to the Amazon Web Services console sign-in page.

    Args:
        domain_id(str): The domain ID.
        user_profile_name(str): The name of the UserProfile to sign-in as.
        session_expiration_duration_in_seconds(int, optional): The session expiration duration in seconds. This value defaults to 43200. Defaults to None.
        expires_in_seconds(int, optional): The number of seconds until the pre-signed URL expires. This value defaults to 300. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.presigned.domain_url.create(
                ctx, domain_id=value, user_profile_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.presigned.domain_url.create domain_id=value, user_profile_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_presigned_domain_url",
        op_kwargs={
            "DomainId": domain_id,
            "UserProfileName": user_profile_name,
            "SessionExpirationDurationInSeconds": session_expiration_duration_in_seconds,
            "ExpiresInSeconds": expires_in_seconds,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def notify(
    hub,
    ctx,
    progress_update_stream: str,
    migration_task_name: str,
    task: Dict,
    update_date_time: str,
    next_update_seconds: int,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Notifies Migration Hub of the current status, progress, or other detail regarding a migration task. This API has the following traits:   Migration tools will call the NotifyMigrationTaskState API to share the latest progress and status.    MigrationTaskName is used for addressing updates to the correct target.    ProgressUpdateStream is used for access control and to provide a namespace for each migration tool.

    Args:
        progress_update_stream(str): The name of the ProgressUpdateStream. .
        migration_task_name(str): Unique identifier that references the migration task. Do not store personal data in this field. .
        task(Dict): Information about the task's progress and status.
        update_date_time(str): The timestamp when the task was gathered.
        next_update_seconds(int): Number of seconds after the UpdateDateTime within which the Migration Hub can expect an update. If Migration Hub does not receive an update within the specified interval, then the migration task will be considered stale.
        dry_run(bool, optional): Optional boolean flag to indicate whether any effect should take place. Used to test if the caller has permission to make the call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgh.migration_task.state.notify(
                ctx,
                progress_update_stream=value,
                migration_task_name=value,
                task=value,
                update_date_time=value,
                next_update_seconds=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgh.migration_task.state.notify progress_update_stream=value, migration_task_name=value, task=value, update_date_time=value, next_update_seconds=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgh",
        operation="notify_migration_task_state",
        op_kwargs={
            "ProgressUpdateStream": progress_update_stream,
            "MigrationTaskName": migration_task_name,
            "Task": task,
            "UpdateDateTime": update_date_time,
            "NextUpdateSeconds": next_update_seconds,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, gateway_name: str, gateway_platform: Dict, tags: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a gateway, which is a virtual or edge device that delivers industrial data streams from local servers to IoT SiteWise. For more information, see Ingesting data using a gateway in the IoT SiteWise User Guide.

    Args:
        gateway_name(str): A unique, friendly name for the gateway.
        gateway_platform(Dict): The gateway's platform. You can only specify one platform in a gateway.
        tags(Dict, optional): A list of key-value pairs that contain metadata for the gateway. For more information, see Tagging your IoT SiteWise resources in the IoT SiteWise User Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotsitewise.gateway.init.create(
                ctx, gateway_name=value, gateway_platform=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotsitewise.gateway.init.create gateway_name=value, gateway_platform=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotsitewise",
        operation="create_gateway",
        op_kwargs={
            "gatewayName": gateway_name,
            "gatewayPlatform": gateway_platform,
            "tags": tags,
        },
    )


async def delete(hub, ctx, gateway_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a gateway from IoT SiteWise. When you delete a gateway, some of the gateway's files remain in your gateway's file system.

    Args:
        gateway_id(str): The ID of the gateway to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotsitewise.gateway.init.delete(ctx, gateway_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotsitewise.gateway.init.delete gateway_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotsitewise",
        operation="delete_gateway",
        op_kwargs={"gatewayId": gateway_id},
    )


async def describe(hub, ctx, gateway_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about a gateway.

    Args:
        gateway_id(str): The ID of the gateway device.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotsitewise.gateway.init.describe(ctx, gateway_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotsitewise.gateway.init.describe gateway_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotsitewise",
        operation="describe_gateway",
        op_kwargs={"gatewayId": gateway_id},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a paginated list of gateways.

    Args:
        next_token(str, optional): The token to be used for the next set of paginated results. Defaults to None.
        max_results(int, optional): The maximum number of results to return for each paginated request. Default: 50. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotsitewise.gateway.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotsitewise.gateway.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotsitewise",
        operation="list_gateways",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )


async def update(hub, ctx, gateway_id: str, gateway_name: str) -> None:
    r"""
    **Autogenerated function**

    Updates a gateway's name.

    Args:
        gateway_id(str): The ID of the gateway to update.
        gateway_name(str): A unique, friendly name for the gateway.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotsitewise.gateway.init.update(
                ctx, gateway_id=value, gateway_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotsitewise.gateway.init.update gateway_id=value, gateway_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotsitewise",
        operation="update_gateway",
        op_kwargs={"gatewayId": gateway_id, "gatewayName": gateway_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    s3_bucket_arn: str,
    s3_config: Dict,
    subdirectory: str = None,
    s3_storage_class: str = None,
    agent_arns: List = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an endpoint for an Amazon S3 bucket. For more information, see https://docs.aws.amazon.com/datasync/latest/userguide/create-locations-cli.html#create-location-s3-cli in the AWS DataSync User Guide.

    Args:
        subdirectory(str, optional): A subdirectory in the Amazon S3 bucket. This subdirectory in Amazon S3 is used to read data from the S3 source location or write data to the S3 destination. Defaults to None.
        s3_bucket_arn(str): The ARN of the Amazon S3 bucket. If the bucket is on an AWS Outpost, this must be an access point ARN.
        s3_storage_class(str, optional): The Amazon S3 storage class that you want to store your files in when this location is used as a task destination. For buckets in AWS Regions, the storage class defaults to Standard. For buckets on AWS Outposts, the storage class defaults to AWS S3 Outposts. For more information about S3 storage classes, see Amazon S3 Storage Classes. Some storage classes have behaviors that can affect your S3 storage cost. For detailed information, see Considerations when working with S3 storage classes in DataSync. Defaults to None.
        s3_config(Dict): The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that is used to access an Amazon S3 bucket. For detailed information about using such a role, see Creating a Location for Amazon S3 in the AWS DataSync User Guide.
        agent_arns(List, optional): If you are using DataSync on an AWS Outpost, specify the Amazon Resource Names (ARNs) of the DataSync agents deployed on your Outpost. For more information about launching a DataSync agent on an AWS Outpost, see Deploy your DataSync agent on AWS Outposts. Defaults to None.
        tags(List, optional): The key-value pair that represents the tag that you want to add to the location. The value can be an empty string. We recommend using tags to name your resources. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datasync.location.s3.create(
                ctx, s3_bucket_arn=value, s3_config=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datasync.location.s3.create s3_bucket_arn=value, s3_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datasync",
        operation="create_location_s3",
        op_kwargs={
            "Subdirectory": subdirectory,
            "S3BucketArn": s3_bucket_arn,
            "S3StorageClass": s3_storage_class,
            "S3Config": s3_config,
            "AgentArns": agent_arns,
            "Tags": tags,
        },
    )


async def describe(hub, ctx, location_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns metadata, such as bucket name, about an Amazon S3 bucket location.

    Args:
        location_arn(str): The Amazon Resource Name (ARN) of the Amazon S3 bucket location to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datasync.location.s3.describe(ctx, location_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datasync.location.s3.describe location_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datasync",
        operation="describe_location_s3",
        op_kwargs={"LocationArn": location_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disable(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Disable portfolio sharing through AWS Organizations feature. This feature will not delete your current shares but it will prevent you from creating new shares throughout your organization. Current shares will not be in sync with your organization structure if it changes after calling this API. This API can only be called by the management account in the organization. This API can't be invoked if there are active delegated administrators in the organization. Note that a delegated administrator is not authorized to invoke DisableAWSOrganizationsAccess.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.aws_organization_access.init.disable(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.aws_organization_access.init.disable
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="disable_aws_organizations_access",
        op_kwargs={},
    )


async def enable(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Enable portfolio sharing feature through AWS Organizations. This API will allow Service Catalog to receive updates on your organization in order to sync your shares with the current structure. This API can only be called by the management account in the organization. By calling this API Service Catalog will make a call to organizations:EnableAWSServiceAccess on your behalf so that your shares can be in sync with any changes in your AWS Organizations structure. Note that a delegated administrator is not authorized to invoke EnableAWSOrganizationsAccess.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.aws_organization_access.init.enable(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.aws_organization_access.init.enable
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="enable_aws_organizations_access",
        op_kwargs={},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub,
    ctx,
    domain_name: str,
    admin_privacy: bool = None,
    registrant_privacy: bool = None,
    tech_privacy: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    This operation updates the specified domain contact's privacy setting. When privacy protection is enabled, contact information such as email address is replaced either with contact information for Amazon Registrar (for .com, .net, and .org domains) or with contact information for our registrar associate, Gandi. This operation affects only the contact information for the specified contact type (registrant, administrator, or tech). If the request succeeds, Amazon Route 53 returns an operation ID that you can use with GetOperationDetail to track the progress and completion of the action. If the request doesn't complete successfully, the domain registrant will be notified by email.  By disabling the privacy service via API, you consent to the publication of the contact information provided for this domain via the public WHOIS database. You certify that you are the registrant of this domain name and have the authority to make this decision. You may withdraw your consent at any time by enabling privacy protection using either UpdateDomainContactPrivacy or the Route 53 console. Enabling privacy protection removes the contact information provided for this domain from the WHOIS database. For more information on our privacy practices, see https://aws.amazon.com/privacy/.

    Args:
        domain_name(str): The name of the domain that you want to update the privacy setting for.
        admin_privacy(bool, optional): Whether you want to conceal contact information from WHOIS queries. If you specify true, WHOIS ("who is") queries return contact information either for Amazon Registrar (for .com, .net, and .org domains) or for our registrar associate, Gandi (for all other TLDs). If you specify false, WHOIS queries return the information that you entered for the admin contact. Defaults to None.
        registrant_privacy(bool, optional): Whether you want to conceal contact information from WHOIS queries. If you specify true, WHOIS ("who is") queries return contact information either for Amazon Registrar (for .com, .net, and .org domains) or for our registrar associate, Gandi (for all other TLDs). If you specify false, WHOIS queries return the information that you entered for the registrant contact (domain owner). Defaults to None.
        tech_privacy(bool, optional): Whether you want to conceal contact information from WHOIS queries. If you specify true, WHOIS ("who is") queries return contact information either for Amazon Registrar (for .com, .net, and .org domains) or for our registrar associate, Gandi (for all other TLDs). If you specify false, WHOIS queries return the information that you entered for the technical contact. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53domain.domain.contact.privacy.update(
                ctx, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53domain.domain.contact.privacy.update domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53domains",
        operation="update_domain_contact_privacy",
        op_kwargs={
            "DomainName": domain_name,
            "AdminPrivacy": admin_privacy,
            "RegistrantPrivacy": registrant_privacy,
            "TechPrivacy": tech_privacy,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "product_for_import"


__func_alias__ = {"list_": "list"}


async def list_(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists all findings-generating solutions (products) that you are subscribed to receive findings from in Security Hub.

    Args:
        next_token(str, optional): The token that is required for pagination. On your first call to the ListEnabledProductsForImport operation, set the value of this parameter to NULL. For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response. Defaults to None.
        max_results(int, optional): The maximum number of items to return in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.enabled.product_for_import_.list(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.enabled.product_for_import.list
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="list_enabled_products_for_import",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, thing_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Get the runtime configuration of a thing.

    Args:
        thing_name(str): The thing name.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.thing_runtime_configuration.get(
                ctx, thing_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.thing_runtime_configuration.get thing_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="get_thing_runtime_configuration",
        op_kwargs={"ThingName": thing_name},
    )


async def update(
    hub, ctx, thing_name: str, telemetry_configuration: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the runtime configuration of a thing.

    Args:
        telemetry_configuration(Dict, optional): Configuration for telemetry service. Defaults to None.
        thing_name(str): The thing name.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.thing_runtime_configuration.update(
                ctx, thing_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.thing_runtime_configuration.update thing_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="update_thing_runtime_configuration",
        op_kwargs={
            "TelemetryConfiguration": telemetry_configuration,
            "ThingName": thing_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, api_id: str, model_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets a model template.

    Args:
        api_id(str): The API identifier.
        model_id(str): The model ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.model.template.get(
                ctx, api_id=value, model_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.model.template.get api_id=value, model_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="get_model_template",
        op_kwargs={"ApiId": api_id, "ModelId": model_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(hub, ctx, global_table_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes Region-specific settings for a global table.  This operation only applies to Version 2017.11.29 of global tables.

    Args:
        global_table_name(str): The name of the global table to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.global_table.setting.describe_all(
                ctx, global_table_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.global_table.setting.describe_all global_table_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="describe_global_table_settings",
        op_kwargs={"GlobalTableName": global_table_name},
    )


async def update_multiple(
    hub,
    ctx,
    global_table_name: str,
    global_table_billing_mode: str = None,
    global_table_provisioned_write_capacity_units: int = None,
    global_table_provisioned_write_capacity_auto_scaling_settings_update: Dict = None,
    global_table_global_secondary_index_settings_update: List = None,
    replica_settings_update: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates settings for a global table.

    Args:
        global_table_name(str): The name of the global table.
        global_table_billing_mode(str, optional): The billing mode of the global table. If GlobalTableBillingMode is not specified, the global table defaults to PROVISIONED capacity billing mode.    PROVISIONED - We recommend using PROVISIONED for predictable workloads. PROVISIONED sets the billing mode to Provisioned Mode.    PAY_PER_REQUEST - We recommend using PAY_PER_REQUEST for unpredictable workloads. PAY_PER_REQUEST sets the billing mode to On-Demand Mode.   . Defaults to None.
        global_table_provisioned_write_capacity_units(int, optional): The maximum number of writes consumed per second before DynamoDB returns a ThrottlingException. . Defaults to None.
        global_table_provisioned_write_capacity_auto_scaling_settings_update(Dict, optional): Auto scaling settings for managing provisioned write capacity for the global table. Defaults to None.
        global_table_global_secondary_index_settings_update(List, optional): Represents the settings of a global secondary index for a global table that will be modified. Defaults to None.
        replica_settings_update(List, optional): Represents the settings for a global table in a Region that will be modified. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.global_table.setting.update_multiple(
                ctx, global_table_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.global_table.setting.update_multiple global_table_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="update_global_table_settings",
        op_kwargs={
            "GlobalTableName": global_table_name,
            "GlobalTableBillingMode": global_table_billing_mode,
            "GlobalTableProvisionedWriteCapacityUnits": global_table_provisioned_write_capacity_units,
            "GlobalTableProvisionedWriteCapacityAutoScalingSettingsUpdate": global_table_provisioned_write_capacity_auto_scaling_settings_update,
            "GlobalTableGlobalSecondaryIndexSettingsUpdate": global_table_global_secondary_index_settings_update,
            "ReplicaSettingsUpdate": replica_settings_update,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def batch(
    hub, ctx, channel_id: str, creates: Dict = None, deletes: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Update a channel schedule

    Args:
        channel_id(str): Id of the channel whose schedule is being updated.
        creates(Dict, optional): Schedule actions to create in the schedule. Defaults to None.
        deletes(Dict, optional): Schedule actions to delete from the schedule. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.update_schedule.batch(ctx, channel_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.update_schedule.batch channel_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="batch_update_schedule",
        op_kwargs={"ChannelId": channel_id, "Creates": creates, "Deletes": deletes},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def decrease(
    hub,
    ctx,
    cluster_name: str,
    new_replication_factor: int,
    availability_zones: List = None,
    node_ids_to_remove: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Removes one or more nodes from a DAX cluster.  You cannot use DecreaseReplicationFactor to remove the last node in a DAX cluster. If you need to do this, use DeleteCluster instead.

    Args:
        cluster_name(str): The name of the DAX cluster from which you want to remove nodes.
        new_replication_factor(int): The new number of nodes for the DAX cluster.
        availability_zones(List, optional): The Availability Zone(s) from which to remove nodes. Defaults to None.
        node_ids_to_remove(List, optional): The unique identifiers of the nodes to be removed from the cluster. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dax.replication_factor.decrease(
                ctx, cluster_name=value, new_replication_factor=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dax.replication_factor.decrease cluster_name=value, new_replication_factor=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dax",
        operation="decrease_replication_factor",
        op_kwargs={
            "ClusterName": cluster_name,
            "NewReplicationFactor": new_replication_factor,
            "AvailabilityZones": availability_zones,
            "NodeIdsToRemove": node_ids_to_remove,
        },
    )


async def increase(
    hub,
    ctx,
    cluster_name: str,
    new_replication_factor: int,
    availability_zones: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds one or more nodes to a DAX cluster.

    Args:
        cluster_name(str): The name of the DAX cluster that will receive additional nodes.
        new_replication_factor(int): The new number of nodes for the DAX cluster.
        availability_zones(List, optional): The Availability Zones (AZs) in which the cluster nodes will be created. All nodes belonging to the cluster are placed in these Availability Zones. Use this parameter if you want to distribute the nodes across multiple AZs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dax.replication_factor.increase(
                ctx, cluster_name=value, new_replication_factor=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dax.replication_factor.increase cluster_name=value, new_replication_factor=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dax",
        operation="increase_replication_factor",
        op_kwargs={
            "ClusterName": cluster_name,
            "NewReplicationFactor": new_replication_factor,
            "AvailabilityZones": availability_zones,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    replication_task_arn: str = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the task assessment results from the Amazon S3 bucket that DMS creates in your account. This action always returns the latest results. For more information about DMS task assessments, see Creating a task assessment report in the  Database Migration Service User Guide.

    Args:
        replication_task_arn(str, optional): The Amazon Resource Name (ARN) string that uniquely identifies the task. When this input parameter is specified, the API returns only one result and ignore the values of the MaxRecords and Marker parameters. . Defaults to None.
        max_records(int, optional):  The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.  Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional):  An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.replication.task.assessment.result.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.replication.task.assessment.result.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="describe_replication_task_assessment_results",
        op_kwargs={
            "ReplicationTaskArn": replication_task_arn,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(hub, ctx, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of tags for the specified resource. Each tag consists of a key and optional value. For more information about tags, see Tagging Resources in the Amazon Managed Blockchain Ethereum Developer Guide, or Tagging Resources in the Amazon Managed Blockchain Hyperledger Fabric Developer Guide.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource. For more information about ARNs and their format, see Amazon Resource Names (ARNs) in the AWS General Reference.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.managedblockchain.tags_for_resource.list(
                ctx, resource_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.managedblockchain.tags_for_resource.list resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="managedblockchain",
        operation="list_tags_for_resource",
        op_kwargs={"ResourceArn": resource_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def bulk(hub, ctx, identity_pool_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Initiates a bulk publish of all existing datasets for an Identity Pool to the configured stream. Customers are limited to one successful bulk publish per 24 hours. Bulk publish is an asynchronous request, customers can see the status of the request via the GetBulkPublishDetails operation.This API can only be called with developer credentials. You cannot call this API with the temporary user credentials provided by Cognito Identity.

    Args:
        identity_pool_id(str): A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_sync.publish.bulk(ctx, identity_pool_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_sync.publish.bulk identity_pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-sync",
        operation="bulk_publish",
        op_kwargs={"IdentityPoolId": identity_pool_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    broker_id: str,
    password: str,
    username: str,
    console_access: bool = None,
    groups: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an ActiveMQ user.

    Args:
        broker_id(str): The unique ID that Amazon MQ generates for the broker.
        console_access(bool, optional): Enables access to the ActiveMQ Web Console for the ActiveMQ user. Defaults to None.
        groups(List, optional): The list of groups (20 maximum) to which the ActiveMQ user belongs. This value can contain only alphanumeric characters, dashes, periods, underscores, and tildes (- . _ ~). This value must be 2-100 characters long. Defaults to None.
        password(str): Required. The password of the user. This value must be at least 12 characters long, must contain at least 4 unique characters, and must not contain commas, colons, or equal signs (,:=).
        username(str): The username of the ActiveMQ user. This value can contain only alphanumeric characters, dashes, periods, underscores, and tildes (- . _ ~). This value must be 2-100 characters long.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mq.user.create(
                ctx, broker_id=value, password=value, username=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mq.user.create broker_id=value, password=value, username=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mq",
        operation="create_user",
        op_kwargs={
            "BrokerId": broker_id,
            "ConsoleAccess": console_access,
            "Groups": groups,
            "Password": password,
            "Username": username,
        },
    )


async def delete(hub, ctx, broker_id: str, username: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an ActiveMQ user.

    Args:
        broker_id(str): The unique ID that Amazon MQ generates for the broker.
        username(str): The username of the ActiveMQ user. This value can contain only alphanumeric characters, dashes, periods, underscores, and tildes (- . _ ~). This value must be 2-100 characters long.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mq.user.delete(ctx, broker_id=value, username=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mq.user.delete broker_id=value, username=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mq",
        operation="delete_user",
        op_kwargs={"BrokerId": broker_id, "Username": username},
    )


async def describe(hub, ctx, broker_id: str, username: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about an ActiveMQ user.

    Args:
        broker_id(str): The unique ID that Amazon MQ generates for the broker.
        username(str): The username of the ActiveMQ user. This value can contain only alphanumeric characters, dashes, periods, underscores, and tildes (- . _ ~). This value must be 2-100 characters long.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mq.user.describe(ctx, broker_id=value, username=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mq.user.describe broker_id=value, username=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mq",
        operation="describe_user",
        op_kwargs={"BrokerId": broker_id, "Username": username},
    )


async def list_all(
    hub, ctx, broker_id: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of all ActiveMQ users.

    Args:
        broker_id(str): The unique ID that Amazon MQ generates for the broker.
        max_results(int, optional): The maximum number of brokers that Amazon MQ can return per page (20 by default). This value must be an integer from 5 to 100. Defaults to None.
        next_token(str, optional): The token that specifies the next page of results Amazon MQ should return. To request the first page, leave nextToken empty. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mq.user.list_all(ctx, broker_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mq.user.list_all broker_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mq",
        operation="list_users",
        op_kwargs={
            "BrokerId": broker_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    broker_id: str,
    username: str,
    console_access: bool = None,
    groups: List = None,
    password: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the information for an ActiveMQ user.

    Args:
        broker_id(str): The unique ID that Amazon MQ generates for the broker.
        console_access(bool, optional): Enables access to the the ActiveMQ Web Console for the ActiveMQ user. Defaults to None.
        groups(List, optional): The list of groups (20 maximum) to which the ActiveMQ user belongs. This value can contain only alphanumeric characters, dashes, periods, underscores, and tildes (- . _ ~). This value must be 2-100 characters long. Defaults to None.
        password(str, optional): The password of the user. This value must be at least 12 characters long, must contain at least 4 unique characters, and must not contain commas, colons, or equal signs (,:=). Defaults to None.
        username(str): The username of the ActiveMQ user. This value can contain only alphanumeric characters, dashes, periods, underscores, and tildes (- . _ ~). This value must be 2-100 characters long.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mq.user.update(ctx, broker_id=value, username=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mq.user.update broker_id=value, username=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mq",
        operation="update_user",
        op_kwargs={
            "BrokerId": broker_id,
            "ConsoleAccess": console_access,
            "Groups": groups,
            "Password": password,
            "Username": username,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, arn: str, artifact_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the pre-signed URL to download a public component artifact. Core devices call this operation to identify the URL that they can use to download an artifact to install.

    Args:
        arn(str): The ARN of the component version. Specify the ARN of a public component version.
        artifact_name(str): The name of the artifact. You can use the GetComponent operation to download the component recipe, which includes the URI of the artifact. The artifact name is the section of the URI after the scheme. For example, in the artifact URI greengrass:SomeArtifact.zip, the artifact name is SomeArtifact.zip.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrassv2.component.version.artifact.get(
                ctx, arn=value, artifact_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrassv2.component.version.artifact.get arn=value, artifact_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrassv2",
        operation="get_component_version_artifact",
        op_kwargs={"arn": arn, "artifactName": artifact_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    template_name: str,
    from_email_address: str,
    template_subject: str,
    template_content: str,
    success_redirection_url: str,
    failure_redirection_url: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new custom verification email template. For more information about custom verification email templates, see Using Custom Verification Email Templates in the Amazon SES Developer Guide. You can execute this operation no more than once per second.

    Args:
        template_name(str): The name of the custom verification email template.
        from_email_address(str): The email address that the custom verification email is sent from.
        template_subject(str): The subject line of the custom verification email.
        template_content(str): The content of the custom verification email. The total size of the email must be less than 10 MB. The message body may contain HTML, with some limitations. For more information, see Custom Verification Email Frequently Asked Questions in the Amazon SES Developer Guide.
        success_redirection_url(str): The URL that the recipient of the verification email is sent to if his or her address is successfully verified.
        failure_redirection_url(str): The URL that the recipient of the verification email is sent to if his or her address is not successfully verified.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.custom_verification_email.template.create(
                ctx,
                template_name=value,
                from_email_address=value,
                template_subject=value,
                template_content=value,
                success_redirection_url=value,
                failure_redirection_url=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.custom_verification_email.template.create template_name=value, from_email_address=value, template_subject=value, template_content=value, success_redirection_url=value, failure_redirection_url=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="create_custom_verification_email_template",
        op_kwargs={
            "TemplateName": template_name,
            "FromEmailAddress": from_email_address,
            "TemplateSubject": template_subject,
            "TemplateContent": template_content,
            "SuccessRedirectionURL": success_redirection_url,
            "FailureRedirectionURL": failure_redirection_url,
        },
    )


async def delete(hub, ctx, template_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an existing custom verification email template. For more information about custom verification email templates, see Using Custom Verification Email Templates in the Amazon SES Developer Guide. You can execute this operation no more than once per second.

    Args:
        template_name(str): The name of the custom verification email template that you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.custom_verification_email.template.delete(
                ctx, template_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.custom_verification_email.template.delete template_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="delete_custom_verification_email_template",
        op_kwargs={"TemplateName": template_name},
    )


async def get(hub, ctx, template_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the custom email verification template for the template name you specify. For more information about custom verification email templates, see Using Custom Verification Email Templates in the Amazon SES Developer Guide. You can execute this operation no more than once per second.

    Args:
        template_name(str): The name of the custom verification email template that you want to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.custom_verification_email.template.get(
                ctx, template_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.custom_verification_email.template.get template_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="get_custom_verification_email_template",
        op_kwargs={"TemplateName": template_name},
    )


async def list_all(hub, ctx, next_token: str = None, page_size: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the existing custom verification email templates for your account in the current AWS Region. For more information about custom verification email templates, see Using Custom Verification Email Templates in the Amazon SES Developer Guide. You can execute this operation no more than once per second.

    Args:
        next_token(str, optional): A token returned from a previous call to ListCustomVerificationEmailTemplates to indicate the position in the list of custom verification email templates. Defaults to None.
        page_size(int, optional): The number of results to show in a single call to ListCustomVerificationEmailTemplates. If the number of results is larger than the number you specified in this parameter, then the response includes a NextToken element, which you can use to obtain additional results. The value you specify has to be at least 1, and can be no more than 50. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.custom_verification_email.template.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.custom_verification_email.template.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="list_custom_verification_email_templates",
        op_kwargs={"NextToken": next_token, "PageSize": page_size},
    )


async def update(
    hub,
    ctx,
    template_name: str,
    from_email_address: str,
    template_subject: str,
    template_content: str,
    success_redirection_url: str,
    failure_redirection_url: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing custom verification email template. For more information about custom verification email templates, see Using Custom Verification Email Templates in the Amazon SES Developer Guide. You can execute this operation no more than once per second.

    Args:
        template_name(str): The name of the custom verification email template that you want to update.
        from_email_address(str): The email address that the custom verification email is sent from.
        template_subject(str): The subject line of the custom verification email.
        template_content(str): The content of the custom verification email. The total size of the email must be less than 10 MB. The message body may contain HTML, with some limitations. For more information, see Custom Verification Email Frequently Asked Questions in the Amazon SES Developer Guide.
        success_redirection_url(str): The URL that the recipient of the verification email is sent to if his or her address is successfully verified.
        failure_redirection_url(str): The URL that the recipient of the verification email is sent to if his or her address is not successfully verified.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.custom_verification_email.template.update(
                ctx,
                template_name=value,
                from_email_address=value,
                template_subject=value,
                template_content=value,
                success_redirection_url=value,
                failure_redirection_url=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.custom_verification_email.template.update template_name=value, from_email_address=value, template_subject=value, template_content=value, success_redirection_url=value, failure_redirection_url=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="update_custom_verification_email_template",
        op_kwargs={
            "TemplateName": template_name,
            "FromEmailAddress": from_email_address,
            "TemplateSubject": template_subject,
            "TemplateContent": template_content,
            "SuccessRedirectionURL": success_redirection_url,
            "FailureRedirectionURL": failure_redirection_url,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def verify(hub, ctx, domain: str) -> Dict:
    r"""
    **Autogenerated function**

    Adds a domain to the list of identities for your Amazon SES account in the current AWS Region and attempts to verify it. For more information about verifying domains, see Verifying Email Addresses and Domains in the Amazon SES Developer Guide.  You can execute this operation no more than once per second.

    Args:
        domain(str): The domain to be verified.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.domain.identity.verify(ctx, domain=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.domain.identity.verify domain=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="verify_domain_identity",
        op_kwargs={"Domain": domain},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def disassociate(hub, ctx, account_id: str, group_names: List) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates the specified sign-in delegate groups from the specified Amazon Chime account.

    Args:
        account_id(str): The Amazon Chime account ID.
        group_names(List): The sign-in delegate group names.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.signin_delegate_group.from_account.disassociate(
                ctx, account_id=value, group_names=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.signin_delegate_group.from_account.disassociate account_id=value, group_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="disassociate_signin_delegate_groups_from_account",
        op_kwargs={"AccountId": account_id, "GroupNames": group_names},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def send(hub, ctx, contact_channel_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Sends an activation code to a contact channel. The contact can use this code to activate the contact channel in the console or with the ActivateChannel action. Incident Manager can't engage a contact channel until it has been activated.

    Args:
        contact_channel_id(str): The Amazon Resource Name (ARN) of the contact channel.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_contact.activation_code.send(ctx, contact_channel_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_contact.activation_code.send contact_channel_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-contacts",
        operation="send_activation_code",
        op_kwargs={"ContactChannelId": contact_channel_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def cancel(
    hub, ctx, cluster_id: str, step_ids: List, step_cancellation_option: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Cancels a pending step or steps in a running cluster. Available only in Amazon EMR versions 4.8.0 and later, excluding version 5.0.0. A maximum of 256 steps are allowed in each CancelSteps request. CancelSteps is idempotent but asynchronous; it does not guarantee that a step will be canceled, even if the request is successfully submitted. When you use Amazon EMR versions 5.28.0 and later, you can cancel steps that are in a PENDING or RUNNING state. In earlier versions of Amazon EMR, you can only cancel steps that are in a PENDING state.

    Args:
        cluster_id(str): The ClusterID for the specified steps that will be canceled. Use RunJobFlow and ListClusters to get ClusterIDs. .
        step_ids(List): The list of StepIDs to cancel. Use ListSteps to get steps and their states for the specified cluster.
        step_cancellation_option(str, optional): The option to choose to cancel RUNNING steps. By default, the value is SEND_INTERRUPT. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.step.cancel(ctx, cluster_id=value, step_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.step.cancel cluster_id=value, step_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="cancel_steps",
        op_kwargs={
            "ClusterId": cluster_id,
            "StepIds": step_ids,
            "StepCancellationOption": step_cancellation_option,
        },
    )


async def describe(hub, ctx, cluster_id: str, step_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides more detail about the cluster step.

    Args:
        cluster_id(str): The identifier of the cluster with steps to describe.
        step_id(str): The identifier of the step to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.step.describe(ctx, cluster_id=value, step_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.step.describe cluster_id=value, step_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="describe_step",
        op_kwargs={"ClusterId": cluster_id, "StepId": step_id},
    )


async def list_all(
    hub,
    ctx,
    cluster_id: str,
    step_states: List = None,
    step_ids: List = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Provides a list of steps for the cluster in reverse order unless you specify stepIds with the request or filter by StepStates. You can specify a maximum of 10 stepIDs. The CLI automatically paginates results to return a list greater than 50 steps. To return more than 50 steps using the CLI, specify a Marker, which is a pagination token that indicates the next set of steps to retrieve.

    Args:
        cluster_id(str): The identifier of the cluster for which to list the steps.
        step_states(List, optional): The filter to limit the step list based on certain states. Defaults to None.
        step_ids(List, optional): The filter to limit the step list based on the identifier of the steps. You can specify a maximum of ten Step IDs. The character constraint applies to the overall length of the array. Defaults to None.
        marker(str, optional): The maximum number of steps that a single ListSteps action returns is 50. To return a longer list of steps, use multiple ListSteps actions along with the Marker parameter, which is a pagination token that indicates the next set of results to retrieve. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.step.list_all(ctx, cluster_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.step.list_all cluster_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="list_steps",
        op_kwargs={
            "ClusterId": cluster_id,
            "StepStates": step_states,
            "StepIds": step_ids,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    fleet_id: str,
    start_time: str = None,
    end_time: str = None,
    limit: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves entries from a fleet's event log. Fleet events are initiated by changes in status, such as during fleet creation and termination, changes in capacity, etc. If a fleet has multiple locations, events are also initiated by changes to status and capacity in remote locations.  You can specify a time range to limit the result set. Use the pagination parameters to retrieve results as a set of sequential pages.  If successful, a collection of event log entries matching the request are returned.  Learn more   Setting up GameLift fleets   Related actions   ListFleets | DescribeEC2InstanceLimits | DescribeFleetAttributes | DescribeFleetCapacity | DescribeFleetEvents | DescribeFleetLocationAttributes | DescribeFleetPortSettings | DescribeFleetUtilization | DescribeRuntimeConfiguration | DescribeScalingPolicies | All APIs by task

    Args:
        fleet_id(str): A unique identifier for the fleet to get event logs for. You can use either the fleet ID or ARN value.
        start_time(str, optional): The earliest date to retrieve event logs for. If no start time is specified, this call returns entries starting from when the fleet was created to the specified end time. Format is a number expressed in Unix time as milliseconds (ex: "1469498468.057"). Defaults to None.
        end_time(str, optional): The most recent date to retrieve event logs for. If no end time is specified, this call returns entries from the specified start time up to the present. Format is a number expressed in Unix time as milliseconds (ex: "1469498468.057"). Defaults to None.
        limit(int, optional): The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages. Defaults to None.
        next_token(str, optional): A token that indicates the start of the next sequential page of results. Use the token that is returned with a previous call to this operation. To start at the beginning of the result set, do not specify a value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.fleet.event.describe_all(ctx, fleet_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.fleet.event.describe_all fleet_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="describe_fleet_events",
        op_kwargs={
            "FleetId": fleet_id,
            "StartTime": start_time,
            "EndTime": end_time,
            "Limit": limit,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def put_multiple(hub, ctx, entries: List) -> Dict:
    r"""
    **Autogenerated function**

    Sends custom events to Amazon EventBridge so that they can be matched to rules.

    Args:
        entries(List): The entry that defines an event in your system. You can specify several parameters for the entry such as the source and type of the event, resources associated with the event, and so on.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.event.init.put_multiple(ctx, entries=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.event.init.put_multiple entries=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="put_events",
        op_kwargs={"Entries": entries},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub,
    ctx,
    authentication_token: str = None,
    user_id: str = None,
    collection_type: str = None,
    limit: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a collection of resources, including folders and documents. The only CollectionType supported is SHARED_WITH_ME.

    Args:
        authentication_token(str, optional): The Amazon WorkDocs authentication token. Not required when using AWS administrator credentials to access the API. Defaults to None.
        user_id(str, optional): The user ID for the resource collection. This is a required field for accessing the API operation using IAM credentials. Defaults to None.
        collection_type(str, optional): The collection type. Defaults to None.
        limit(int, optional): The maximum number of resources to return. Defaults to None.
        marker(str, optional): The marker for the next set of results. This marker was received from a previous call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.resource.init.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.resource.init.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="get_resources",
        op_kwargs={
            "AuthenticationToken": authentication_token,
            "UserId": user_id,
            "CollectionType": collection_type,
            "Limit": limit,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, volume_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a snapshot of a volume. You can take snapshots of your gateway volumes on a scheduled or ad hoc basis. This API action enables you to delete a snapshot schedule for a volume. For more information, see Backing up your volumes. In the DeleteSnapshotSchedule request, you identify the volume by providing its Amazon Resource Name (ARN). This operation is only supported in stored and cached volume gateway types.  To list or delete a snapshot, you must use the Amazon EC2 API. For more information, go to DescribeSnapshots in the Amazon Elastic Compute Cloud API Reference.

    Args:
        volume_arn(str): The volume which snapshot schedule to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.snapshot.schedule.delete(ctx, volume_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.snapshot.schedule.delete volume_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="delete_snapshot_schedule",
        op_kwargs={"VolumeARN": volume_arn},
    )


async def describe(hub, ctx, volume_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the snapshot schedule for the specified gateway volume. The snapshot schedule information includes intervals at which snapshots are automatically initiated on the volume. This operation is only supported in the cached volume and stored volume types.

    Args:
        volume_arn(str): The Amazon Resource Name (ARN) of the volume. Use the ListVolumes operation to return a list of gateway volumes.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.snapshot.schedule.describe(ctx, volume_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.snapshot.schedule.describe volume_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="describe_snapshot_schedule",
        op_kwargs={"VolumeARN": volume_arn},
    )


async def update(
    hub,
    ctx,
    volume_arn: str,
    start_at: int,
    recurrence_in_hours: int,
    description: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a snapshot schedule configured for a gateway volume. This operation is only supported in the cached volume and stored volume gateway types. The default snapshot schedule for volume is once every 24 hours, starting at the creation time of the volume. You can use this API to change the snapshot schedule configured for the volume. In the request you must identify the gateway volume whose snapshot schedule you want to update, and the schedule information, including when you want the snapshot to begin on a day and the frequency (in hours) of snapshots.

    Args:
        volume_arn(str): The Amazon Resource Name (ARN) of the volume. Use the ListVolumes operation to return a list of gateway volumes.
        start_at(int): The hour of the day at which the snapshot schedule begins represented as hh, where hh is the hour (0 to 23). The hour of the day is in the time zone of the gateway.
        recurrence_in_hours(int): Frequency of snapshots. Specify the number of hours between snapshots.
        description(str, optional): Optional description of the snapshot that overwrites the existing description. Defaults to None.
        tags(List, optional): A list of up to 50 tags that can be assigned to a snapshot. Each tag is a key-value pair.  Valid characters for key and value are letters, spaces, and numbers representable in UTF-8 format, and the following special characters: + - = . _ : / @. The maximum length of a tag's key is 128 characters, and the maximum length for a tag's value is 256. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.snapshot.schedule.update(
                ctx, volume_arn=value, start_at=value, recurrence_in_hours=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.snapshot.schedule.update volume_arn=value, start_at=value, recurrence_in_hours=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="update_snapshot_schedule",
        op_kwargs={
            "VolumeARN": volume_arn,
            "StartAt": start_at,
            "RecurrenceInHours": recurrence_in_hours,
            "Description": description,
            "Tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, filter_: Dict = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the current handshakes that are associated with the account of the requesting user. Handshakes that are ACCEPTED, DECLINED, or CANCELED appear in the results of this API for only 30 days after changing to that state. After that, they're deleted and no longer accessible.  Always check the NextToken response parameter for a null value when calling a List* operation. These operations can occasionally return an empty set of results even when there are more results available. The NextToken response parameter value is null only when there are no more results to display.  This operation can be called from any account in the organization.

    Args:
        filter_(Dict, optional): Filters the handshakes that you want included in the response. The default is all types. Use the ActionType element to limit the output to only a specified type, such as INVITE, ENABLE_ALL_FEATURES, or APPROVE_ALL_FEATURES. Alternatively, for the ENABLE_ALL_FEATURES handshake that generates a separate child handshake for each member account, you can specify ParentHandshakeId to see only the handshakes that were generated by that parent request. Defaults to None.
        next_token(str, optional): The parameter for receiving additional results if you receive a NextToken response in a previous request. A NextToken response indicates that more output is available. Set this parameter to the value of the previous call's NextToken response to indicate where the output should continue from. Defaults to None.
        max_results(int, optional): The total number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value that is specific to the operation. If additional items exist beyond the maximum you specify, the NextToken response element is present and has a value (is not null). Include that value as the NextToken request parameter in the next call to the operation to get the next part of the results. Note that Organizations might return fewer results than the maximum even when there are more results available. You should check NextToken after every operation to ensure that you receive all of the results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.handshake.for_.account.list(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.handshake.for_.account.list
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="list_handshakes_for_account",
        op_kwargs={
            "Filter": filter_,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Describes the IAM role that enables Amazon Inspector to access your AWS account.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.cross_account_access_role.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.cross_account_access_role.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="describe_cross_account_access_role",
        op_kwargs={},
    )


async def register(hub, ctx, role_arn: str) -> None:
    r"""
    **Autogenerated function**

    Registers the IAM role that grants Amazon Inspector access to AWS Services needed to perform security assessments.

    Args:
        role_arn(str): The ARN of the IAM role that grants Amazon Inspector access to AWS Services needed to perform security assessments. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.cross_account_access_role.register(
                ctx, role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.cross_account_access_role.register role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="register_cross_account_access_role",
        op_kwargs={"roleArn": role_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    job_id: str,
    max_results: int = None,
    next_token: str = None,
    sort_by: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the label detection results of a Amazon Rekognition Video analysis started by StartLabelDetection.  The label detection operation is started by a call to StartLabelDetection which returns a job identifier (JobId). When the label detection operation finishes, Amazon Rekognition publishes a completion status to the Amazon Simple Notification Service topic registered in the initial call to StartlabelDetection. To get the results of the label detection operation, first check that the status value published to the Amazon SNS topic is SUCCEEDED. If so, call GetLabelDetection and pass the job identifier (JobId) from the initial call to StartLabelDetection.  GetLabelDetection returns an array of detected labels (Labels) sorted by the time the labels were detected. You can also sort by the label name by specifying NAME for the SortBy input parameter. The labels returned include the label name, the percentage confidence in the accuracy of the detected label, and the time the label was detected in the video. The returned labels also include bounding box information for common objects, a hierarchical taxonomy of detected labels, and the version of the label model used for detection. Use MaxResults parameter to limit the number of labels returned. If there are more results than specified in MaxResults, the value of NextToken in the operation response contains a pagination token for getting the next set of results. To get the next page of results, call GetlabelDetection and populate the NextToken request parameter with the token value returned from the previous call to GetLabelDetection.

    Args:
        job_id(str): Job identifier for the label detection operation for which you want results returned. You get the job identifer from an initial call to StartlabelDetection.
        max_results(int, optional): Maximum number of results to return per paginated call. The largest value you can specify is 1000. If you specify a value greater than 1000, a maximum of 1000 results is returned. The default value is 1000. Defaults to None.
        next_token(str, optional): If the previous response was incomplete (because there are more labels to retrieve), Amazon Rekognition Video returns a pagination token in the response. You can use this pagination token to retrieve the next set of labels. . Defaults to None.
        sort_by(str, optional): Sort to use for elements in the Labels array. Use TIMESTAMP to sort array elements by the time labels are detected. Use NAME to alphabetically group elements for a label together. Within each label group, the array element are sorted by detection confidence. The default sort is by TIMESTAMP. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.label.detection.get(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.label.detection.get job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="get_label_detection",
        op_kwargs={
            "JobId": job_id,
            "MaxResults": max_results,
            "NextToken": next_token,
            "SortBy": sort_by,
        },
    )


async def start(
    hub,
    ctx,
    video: Dict,
    client_request_token: str = None,
    min_confidence: float = None,
    notification_channel: Dict = None,
    job_tag: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts asynchronous detection of labels in a stored video. Amazon Rekognition Video can detect labels in a video. Labels are instances of real-world entities. This includes objects like flower, tree, and table; events like wedding, graduation, and birthday party; concepts like landscape, evening, and nature; and activities like a person getting out of a car or a person skiing. The video must be stored in an Amazon S3 bucket. Use Video to specify the bucket name and the filename of the video. StartLabelDetection returns a job identifier (JobId) which you use to get the results of the operation. When label detection is finished, Amazon Rekognition Video publishes a completion status to the Amazon Simple Notification Service topic that you specify in NotificationChannel. To get the results of the label detection operation, first check that the status value published to the Amazon SNS topic is SUCCEEDED. If so, call GetLabelDetection and pass the job identifier (JobId) from the initial call to StartLabelDetection.

    Args:
        video(Dict): The video in which you want to detect labels. The video must be stored in an Amazon S3 bucket.
        client_request_token(str, optional): Idempotent token used to identify the start request. If you use the same token with multiple StartLabelDetection requests, the same JobId is returned. Use ClientRequestToken to prevent the same job from being accidently started more than once. . Defaults to None.
        min_confidence(float, optional): Specifies the minimum confidence that Amazon Rekognition Video must have in order to return a detected label. Confidence represents how certain Amazon Rekognition is that a label is correctly identified.0 is the lowest confidence. 100 is the highest confidence. Amazon Rekognition Video doesn't return any labels with a confidence level lower than this specified value. If you don't specify MinConfidence, the operation returns labels with confidence values greater than or equal to 50 percent. Defaults to None.
        notification_channel(Dict, optional): The Amazon SNS topic ARN you want Amazon Rekognition Video to publish the completion status of the label detection operation to. . Defaults to None.
        job_tag(str, optional): An identifier you specify that's returned in the completion notification that's published to your Amazon Simple Notification Service topic. For example, you can use JobTag to group related jobs and identify them in the completion notification. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.label.detection.start(ctx, video=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.label.detection.start video=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="start_label_detection",
        op_kwargs={
            "Video": video,
            "ClientRequestToken": client_request_token,
            "MinConfidence": min_confidence,
            "NotificationChannel": notification_channel,
            "JobTag": job_tag,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Associates the specified tags to a resource with the specified resourceArn. If existing tags on a resource aren't specified in the request parameters, they aren't changed. When a resource is deleted, the tags associated with that resource are also deleted.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource to add tags to.
        tags(List): The tags to add to the resource. A tag is an array of key-value pairs. Tag keys can have a maximum character length of 128 characters, and tag values can have a maximum length of 256 characters.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appmesh.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appmesh.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appmesh",
        operation="tag_resource",
        op_kwargs={"resourceArn": resource_arn, "tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Deletes specified tags from a resource.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource to delete tags from.
        tag_keys(List): The keys of the tags to be removed.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appmesh.resource.untag(ctx, resource_arn=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appmesh.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appmesh",
        operation="untag_resource",
        op_kwargs={"resourceArn": resource_arn, "tagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def test(
    hub,
    ctx,
    server_id: str,
    user_name: str,
    server_protocol: str = None,
    source_ip: str = None,
    user_password: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    If the IdentityProviderType of a file transfer protocol-enabled server is AWS_DIRECTORY_SERVICE or API_Gateway, tests whether your identity provider is set up successfully. We highly recommend that you call this operation to test your authentication method as soon as you create your server. By doing so, you can troubleshoot issues with the identity provider integration to ensure that your users can successfully use the service.

    Args:
        server_id(str): A system-assigned identifier for a specific server. That server's user authentication method is tested with a user name and password.
        server_protocol(str, optional): The type of file transfer protocol to be tested. The available protocols are:   Secure Shell (SSH) File Transfer Protocol (SFTP)   File Transfer Protocol Secure (FTPS)   File Transfer Protocol (FTP)  . Defaults to None.
        source_ip(str, optional): The source IP address of the user account to be tested. Defaults to None.
        user_name(str): The name of the user account to be tested.
        user_password(str, optional): The password of the user account to be tested. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transfer.identity_provider.test(
                ctx, server_id=value, user_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transfer.identity_provider.test server_id=value, user_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transfer",
        operation="test_identity_provider",
        op_kwargs={
            "ServerId": server_id,
            "ServerProtocol": server_protocol,
            "SourceIp": source_ip,
            "UserName": user_name,
            "UserPassword": user_password,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, recovery_group_name: str, cells: List = None, tags: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new Recovery Group.

    Args:
        cells(List, optional): A list of Cell arns. Defaults to None.
        recovery_group_name(str): The name of the RecoveryGroup to create.
        tags(Dict, optional): A collection of tags associated with a resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_readiness.recovery_group.init.create(
                ctx, recovery_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_readiness.recovery_group.init.create recovery_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-readiness",
        operation="create_recovery_group",
        op_kwargs={
            "Cells": cells,
            "RecoveryGroupName": recovery_group_name,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, recovery_group_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes an existing Recovery Group.

    Args:
        recovery_group_name(str): The RecoveryGroup to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_readiness.recovery_group.init.delete(
                ctx, recovery_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_readiness.recovery_group.init.delete recovery_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-readiness",
        operation="delete_recovery_group",
        op_kwargs={"RecoveryGroupName": recovery_group_name},
    )


async def get(hub, ctx, recovery_group_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a Recovery Group.

    Args:
        recovery_group_name(str): The RecoveryGroup to get.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_readiness.recovery_group.init.get(
                ctx, recovery_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_readiness.recovery_group.init.get recovery_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-readiness",
        operation="get_recovery_group",
        op_kwargs={"RecoveryGroupName": recovery_group_name},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a collection of Recovery Groups.

    Args:
        max_results(int, optional): Upper bound on number of records to return. Defaults to None.
        next_token(str, optional): A token used to resume pagination from the end of a previous request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_readiness.recovery_group.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_readiness.recovery_group.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-readiness",
        operation="list_recovery_groups",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(hub, ctx, cells: List, recovery_group_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing Recovery Group.

    Args:
        cells(List): A list of Cell arns, completely replaces previous list.
        recovery_group_name(str): The RecoveryGroup to update.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_readiness.recovery_group.init.update(
                ctx, cells=value, recovery_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_readiness.recovery_group.init.update cells=value, recovery_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-readiness",
        operation="update_recovery_group",
        op_kwargs={"Cells": cells, "RecoveryGroupName": recovery_group_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def send(
    hub,
    ctx,
    content: Dict,
    from_email_address: str = None,
    from_email_address_identity_arn: str = None,
    destination: Dict = None,
    reply_to_addresses: List = None,
    feedback_forwarding_email_address: str = None,
    feedback_forwarding_email_address_identity_arn: str = None,
    email_tags: List = None,
    configuration_set_name: str = None,
    list_management_options: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Sends an email message. You can use the Amazon SES API v2 to send two types of messages:    Simple – A standard email message. When you create this type of message, you specify the sender, the recipient, and the message body, and Amazon SES assembles the message for you.    Raw – A raw, MIME-formatted email message. When you send this type of email, you have to specify all of the message headers, as well as the message body. You can use this message type to send messages that contain attachments. The message that you specify has to be a valid MIME message.    Templated – A message that contains personalization tags. When you send this type of email, Amazon SES API v2 automatically replaces the tags with values that you specify.

    Args:
        from_email_address(str, optional): The email address that you want to use as the "From" address for the email. The address that you specify has to be verified. . Defaults to None.
        from_email_address_identity_arn(str, optional): This parameter is used only for sending authorization. It is the ARN of the identity that is associated with the sending authorization policy that permits you to use the email address specified in the FromEmailAddress parameter. For example, if the owner of example.com (which has ARN arn:aws:ses:us-east-1:123456789012:identity/example.com) attaches a policy to it that authorizes you to use sender@example.com, then you would specify the FromEmailAddressIdentityArn to be arn:aws:ses:us-east-1:123456789012:identity/example.com, and the FromEmailAddress to be sender@example.com. For more information about sending authorization, see the Amazon SES Developer Guide. For Raw emails, the FromEmailAddressIdentityArn value overrides the X-SES-SOURCE-ARN and X-SES-FROM-ARN headers specified in raw email message content. Defaults to None.
        destination(Dict, optional): An object that contains the recipients of the email message. Defaults to None.
        reply_to_addresses(List, optional): The "Reply-to" email addresses for the message. When the recipient replies to the message, each Reply-to address receives the reply. Defaults to None.
        feedback_forwarding_email_address(str, optional): The address that you want bounce and complaint notifications to be sent to. Defaults to None.
        feedback_forwarding_email_address_identity_arn(str, optional): This parameter is used only for sending authorization. It is the ARN of the identity that is associated with the sending authorization policy that permits you to use the email address specified in the FeedbackForwardingEmailAddress parameter. For example, if the owner of example.com (which has ARN arn:aws:ses:us-east-1:123456789012:identity/example.com) attaches a policy to it that authorizes you to use feedback@example.com, then you would specify the FeedbackForwardingEmailAddressIdentityArn to be arn:aws:ses:us-east-1:123456789012:identity/example.com, and the FeedbackForwardingEmailAddress to be feedback@example.com. For more information about sending authorization, see the Amazon SES Developer Guide. Defaults to None.
        content(Dict): An object that contains the body of the message. You can send either a Simple message Raw message or a template Message.
        email_tags(List, optional): A list of tags, in the form of name/value pairs, to apply to an email that you send using the SendEmail operation. Tags correspond to characteristics of the email that you define, so that you can publish email sending events. . Defaults to None.
        configuration_set_name(str, optional): The name of the configuration set that you want to use when sending the email. Defaults to None.
        list_management_options(Dict, optional): An object used to specify a list or topic to which an email belongs, which will be used when a contact chooses to unsubscribe. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.email.init.send(ctx, content=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.email.init.send content=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="send_email",
        op_kwargs={
            "FromEmailAddress": from_email_address,
            "FromEmailAddressIdentityArn": from_email_address_identity_arn,
            "Destination": destination,
            "ReplyToAddresses": reply_to_addresses,
            "FeedbackForwardingEmailAddress": feedback_forwarding_email_address,
            "FeedbackForwardingEmailAddressIdentityArn": feedback_forwarding_email_address_identity_arn,
            "Content": content,
            "EmailTags": email_tags,
            "ConfigurationSetName": configuration_set_name,
            "ListManagementOptions": list_management_options,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(
    hub, ctx, bucket: str, id_: str, expected_bucket_owner: str = None
) -> None:
    r"""
    **Autogenerated function**

    Deletes an analytics configuration for the bucket (specified by the analytics configuration ID). To use this operation, you must have permissions to perform the s3:PutAnalyticsConfiguration action. The bucket owner has this permission by default. The bucket owner can grant this permission to others. For more information about permissions, see Permissions Related to Bucket Subresource Operations and Managing Access Permissions to Your Amazon S3 Resources. For information about the Amazon S3 analytics feature, see Amazon S3 Analytics – Storage Class Analysis.  The following operations are related to DeleteBucketAnalyticsConfiguration:    GetBucketAnalyticsConfiguration     ListBucketAnalyticsConfigurations     PutBucketAnalyticsConfiguration

    Args:
        bucket(str): The name of the bucket from which an analytics configuration is deleted.
        id_(str): The ID that identifies the analytics configuration.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.analytic_configuration.delete(
                ctx, bucket=value, id_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.analytic_configuration.delete bucket=value, id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="delete_bucket_analytics_configuration",
        op_kwargs={
            "Bucket": bucket,
            "Id": id_,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )


async def get(
    hub, ctx, bucket: str, id_: str, expected_bucket_owner: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    This implementation of the GET action returns an analytics configuration (identified by the analytics configuration ID) from the bucket. To use this operation, you must have permissions to perform the s3:GetAnalyticsConfiguration action. The bucket owner has this permission by default. The bucket owner can grant this permission to others. For more information about permissions, see  Permissions Related to Bucket Subresource Operations and Managing Access Permissions to Your Amazon S3 Resources in the Amazon S3 User Guide.  For information about Amazon S3 analytics feature, see Amazon S3 Analytics – Storage Class Analysis in the Amazon S3 User Guide.  Related Resources     DeleteBucketAnalyticsConfiguration     ListBucketAnalyticsConfigurations     PutBucketAnalyticsConfiguration

    Args:
        bucket(str): The name of the bucket from which an analytics configuration is retrieved.
        id_(str): The ID that identifies the analytics configuration.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.analytic_configuration.get(
                ctx, bucket=value, id_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.analytic_configuration.get bucket=value, id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="get_bucket_analytics_configuration",
        op_kwargs={
            "Bucket": bucket,
            "Id": id_,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )


async def list_all(
    hub,
    ctx,
    bucket: str,
    continuation_token: str = None,
    expected_bucket_owner: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the analytics configurations for the bucket. You can have up to 1,000 analytics configurations per bucket. This action supports list pagination and does not return more than 100 configurations at a time. You should always check the IsTruncated element in the response. If there are no more configurations to list, IsTruncated is set to false. If there are more configurations to list, IsTruncated is set to true, and there will be a value in NextContinuationToken. You use the NextContinuationToken value to continue the pagination of the list by passing the value in continuation-token in the request to GET the next page. To use this operation, you must have permissions to perform the s3:GetAnalyticsConfiguration action. The bucket owner has this permission by default. The bucket owner can grant this permission to others. For more information about permissions, see Permissions Related to Bucket Subresource Operations and Managing Access Permissions to Your Amazon S3 Resources. For information about Amazon S3 analytics feature, see Amazon S3 Analytics – Storage Class Analysis.  The following operations are related to ListBucketAnalyticsConfigurations:    GetBucketAnalyticsConfiguration     DeleteBucketAnalyticsConfiguration     PutBucketAnalyticsConfiguration

    Args:
        bucket(str): The name of the bucket from which analytics configurations are retrieved.
        continuation_token(str, optional): The ContinuationToken that represents a placeholder from where this request should begin. Defaults to None.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.analytic_configuration.list_all(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.analytic_configuration.list_all bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="list_bucket_analytics_configurations",
        op_kwargs={
            "Bucket": bucket,
            "ContinuationToken": continuation_token,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )


async def put(
    hub,
    ctx,
    bucket: str,
    id_: str,
    analytics_configuration: Dict,
    expected_bucket_owner: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Sets an analytics configuration for the bucket (specified by the analytics configuration ID). You can have up to 1,000 analytics configurations per bucket. You can choose to have storage class analysis export analysis reports sent to a comma-separated values (CSV) flat file. See the DataExport request element. Reports are updated daily and are based on the object filters that you configure. When selecting data export, you specify a destination bucket and an optional destination prefix where the file is written. You can export the data to a destination bucket in a different account. However, the destination bucket must be in the same Region as the bucket that you are making the PUT analytics configuration to. For more information, see Amazon S3 Analytics – Storage Class Analysis.   You must create a bucket policy on the destination bucket where the exported file is written to grant permissions to Amazon S3 to write objects to the bucket. For an example policy, see Granting Permissions for Amazon S3 Inventory and Storage Class Analysis.  To use this operation, you must have permissions to perform the s3:PutAnalyticsConfiguration action. The bucket owner has this permission by default. The bucket owner can grant this permission to others. For more information about permissions, see Permissions Related to Bucket Subresource Operations and Managing Access Permissions to Your Amazon S3 Resources.  Special Errors       HTTP Error: HTTP 400 Bad Request     Code: InvalidArgument     Cause: Invalid argument.         HTTP Error: HTTP 400 Bad Request     Code: TooManyConfigurations     Cause: You are attempting to create a new configuration but have already reached the 1,000-configuration limit.         HTTP Error: HTTP 403 Forbidden     Code: AccessDenied     Cause: You are not the owner of the specified bucket, or you do not have the s3:PutAnalyticsConfiguration bucket permission to set the configuration on the bucket.       Related Resources     GetBucketAnalyticsConfiguration     DeleteBucketAnalyticsConfiguration     ListBucketAnalyticsConfigurations

    Args:
        bucket(str): The name of the bucket to which an analytics configuration is stored.
        id_(str): The ID that identifies the analytics configuration.
        analytics_configuration(Dict): The configuration and any analyses for the analytics filter.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.analytic_configuration.put(
                ctx, bucket=value, id_=value, analytics_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.analytic_configuration.put bucket=value, id_=value, analytics_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="put_bucket_analytics_configuration",
        op_kwargs={
            "Bucket": bucket,
            "Id": id_,
            "AnalyticsConfiguration": analytics_configuration,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    client_request_token: str,
    invitation_id: str,
    network_id: str,
    member_configuration: Dict,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a member within a Managed Blockchain network. Applies only to Hyperledger Fabric.

    Args:
        client_request_token(str): A unique, case-sensitive identifier that you provide to ensure the idempotency of the operation. An idempotent operation completes no more than one time. This identifier is required only if you make a service request directly using an HTTP client. It is generated automatically if you use an AWS SDK or the AWS CLI.
        invitation_id(str): The unique identifier of the invitation that is sent to the member to join the network.
        network_id(str): The unique identifier of the network in which the member is created.
        member_configuration(Dict): Member configuration parameters.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.managedblockchain.member.create(
                ctx,
                client_request_token=value,
                invitation_id=value,
                network_id=value,
                member_configuration=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.managedblockchain.member.create client_request_token=value, invitation_id=value, network_id=value, member_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="managedblockchain",
        operation="create_member",
        op_kwargs={
            "ClientRequestToken": client_request_token,
            "InvitationId": invitation_id,
            "NetworkId": network_id,
            "MemberConfiguration": member_configuration,
        },
    )


async def delete(hub, ctx, network_id: str, member_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a member. Deleting a member removes the member and all associated resources from the network. DeleteMember can only be called for a specified MemberId if the principal performing the action is associated with the AWS account that owns the member. In all other cases, the DeleteMember action is carried out as the result of an approved proposal to remove a member. If MemberId is the last member in a network specified by the last AWS account, the network is deleted also. Applies only to Hyperledger Fabric.

    Args:
        network_id(str): The unique identifier of the network from which the member is removed.
        member_id(str): The unique identifier of the member to remove.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.managedblockchain.member.delete(
                ctx, network_id=value, member_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.managedblockchain.member.delete network_id=value, member_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="managedblockchain",
        operation="delete_member",
        op_kwargs={"NetworkId": network_id, "MemberId": member_id},
    )


async def get(hub, ctx, network_id: str, member_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns detailed information about a member. Applies only to Hyperledger Fabric.

    Args:
        network_id(str): The unique identifier of the network to which the member belongs.
        member_id(str): The unique identifier of the member.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.managedblockchain.member.get(
                ctx, network_id=value, member_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.managedblockchain.member.get network_id=value, member_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="managedblockchain",
        operation="get_member",
        op_kwargs={"NetworkId": network_id, "MemberId": member_id},
    )


async def list_all(
    hub,
    ctx,
    network_id: str,
    name: str = None,
    status: str = None,
    is_owned: bool = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of the members in a network and properties of their configurations. Applies only to Hyperledger Fabric.

    Args:
        network_id(str): The unique identifier of the network for which to list members.
        name(str, optional): The optional name of the member to list. Defaults to None.
        status(str, optional): An optional status specifier. If provided, only members currently in this status are listed. Defaults to None.
        is_owned(bool, optional): An optional Boolean value. If provided, the request is limited either to members that the current AWS account owns (true) or that other AWS accounts own (false). If omitted, all members are listed. Defaults to None.
        max_results(int, optional): The maximum number of members to return in the request. Defaults to None.
        next_token(str, optional): The pagination token that indicates the next set of results to retrieve. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.managedblockchain.member.list_all(ctx, network_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.managedblockchain.member.list_all network_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="managedblockchain",
        operation="list_members",
        op_kwargs={
            "NetworkId": network_id,
            "Name": name,
            "Status": status,
            "IsOwned": is_owned,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub, ctx, network_id: str, member_id: str, log_publishing_configuration: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a member configuration with new parameters. Applies only to Hyperledger Fabric.

    Args:
        network_id(str): The unique identifier of the Managed Blockchain network to which the member belongs.
        member_id(str): The unique identifier of the member.
        log_publishing_configuration(Dict, optional): Configuration properties for publishing to Amazon CloudWatch Logs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.managedblockchain.member.update(
                ctx, network_id=value, member_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.managedblockchain.member.update network_id=value, member_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="managedblockchain",
        operation="update_member",
        op_kwargs={
            "NetworkId": network_id,
            "MemberId": member_id,
            "LogPublishingConfiguration": log_publishing_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def search(
    hub, ctx, index_name: str, position: List, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Reverse geocodes a given coordinate and returns a legible address. Allows you to search for Places or points of interest near a given position.

    Args:
        index_name(str): The name of the place index resource you want to use for the search.
        max_results(int, optional): An optional paramer. The maximum number of results returned per request.  Default value: 50 . Defaults to None.
        position(List): Specifies a coordinate for the query defined by a longitude, and latitude.   The first position is the X coordinate, or longitude.   The second position is the Y coordinate, or latitude.    For example, position=xLongitude&position=yLatitude .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.place_index.for_.position.search(
                ctx, index_name=value, position=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.place_index.for_.position.search index_name=value, position=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="search_place_index_for_position",
        op_kwargs={
            "IndexName": index_name,
            "MaxResults": max_results,
            "Position": position,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def add(hub, ctx, subscription_name: str, source_identifier: str) -> Dict:
    r"""
    **Autogenerated function**

    Adds a source identifier to an existing RDS event notification subscription.

    Args:
        subscription_name(str): The name of the RDS event notification subscription you want to add a source identifier to.
        source_identifier(str): The identifier of the event source to be added. Constraints:   If the source type is a DB instance, a DBInstanceIdentifier value must be supplied.   If the source type is a DB cluster, a DBClusterIdentifier value must be supplied.   If the source type is a DB parameter group, a DBParameterGroupName value must be supplied.   If the source type is a DB security group, a DBSecurityGroupName value must be supplied.   If the source type is a DB snapshot, a DBSnapshotIdentifier value must be supplied.   If the source type is a DB cluster snapshot, a DBClusterSnapshotIdentifier value must be supplied.  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.source.identifier.to_subscription.add(
                ctx, subscription_name=value, source_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.source.identifier.to_subscription.add subscription_name=value, source_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="add_source_identifier_to_subscription",
        op_kwargs={
            "SubscriptionName": subscription_name,
            "SourceIdentifier": source_identifier,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disassociate(
    hub, ctx, worker_id: str, qualification_type_id: str, reason: str = None
) -> Dict:
    r"""
    **Autogenerated function**

     The DisassociateQualificationFromWorker revokes a previously granted Qualification from a user.   You can provide a text message explaining why the Qualification was revoked. The user who had the Qualification can see this message.

    Args:
        worker_id(str): The ID of the Worker who possesses the Qualification to be revoked.
        qualification_type_id(str): The ID of the Qualification type of the Qualification to be revoked.
        reason(str, optional): A text message that explains why the Qualification was revoked. The user who had the Qualification sees this message. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.qualification.from_worker.disassociate(
                ctx, worker_id=value, qualification_type_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.qualification.from_worker.disassociate worker_id=value, qualification_type_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="disassociate_qualification_from_worker",
        op_kwargs={
            "WorkerId": worker_id,
            "QualificationTypeId": qualification_type_id,
            "Reason": reason,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def upgrade(
    hub, ctx, published_schema_arn: str, directory_arn: str, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Upgrades a single directory in-place using the PublishedSchemaArn with schema updates found in MinorVersion. Backwards-compatible minor version upgrades are instantaneously available for readers on all objects in the directory. Note: This is a synchronous API call and upgrades only one schema on a given directory per call. To upgrade multiple directories from one schema, you would need to call this API on each directory.

    Args:
        published_schema_arn(str): The revision of the published schema to upgrade the directory to.
        directory_arn(str): The ARN for the directory to which the upgraded schema will be applied.
        dry_run(bool, optional): Used for testing whether the major version schemas are backward compatible or not. If schema compatibility fails, an exception would be thrown else the call would succeed but no changes will be saved. This parameter is optional. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.applied_schema.init.upgrade(
                ctx, published_schema_arn=value, directory_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.applied_schema.init.upgrade published_schema_arn=value, directory_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="upgrade_applied_schema",
        op_kwargs={
            "PublishedSchemaArn": published_schema_arn,
            "DirectoryArn": directory_arn,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, principal: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the things associated with the specified principal. A principal can be X.509 certificates, IAM users, groups, and roles, Amazon Cognito identities or federated identities.

    Args:
        next_token(str, optional): To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in this operation. Defaults to None.
        principal(str): The principal.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.principal.thing.list_all(ctx, principal=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.principal.thing.list_all principal=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_principal_things",
        op_kwargs={
            "nextToken": next_token,
            "maxResults": max_results,
            "principal": principal,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(hub, ctx, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the names of stored connections to GitHub accounts.

    Args:
        next_token(str, optional): An identifier returned from the previous ListGitHubAccountTokenNames call. It can be used to return the next set of names in the list. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.git_hub_account_token.name.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.git_hub_account_token.name.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="list_git_hub_account_token_names",
        op_kwargs={"nextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(
    hub,
    ctx,
    standards_subscription_arns: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of the standards that are currently enabled.

    Args:
        standards_subscription_arns(List, optional): The list of the standards subscription ARNs for the standards to retrieve. Defaults to None.
        next_token(str, optional): The token that is required for pagination. On your first call to the GetEnabledStandards operation, set the value of this parameter to NULL. For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response. Defaults to None.
        max_results(int, optional): The maximum number of results to return in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.enabled.standard.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.enabled.standard.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="get_enabled_standards",
        op_kwargs={
            "StandardsSubscriptionArns": standards_subscription_arns,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, device_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes a device from Alexa For Business.

    Args:
        device_arn(str): The ARN of the device for which to request details.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.device.init.delete(ctx, device_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.device.init.delete device_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="delete_device",
        op_kwargs={"DeviceArn": device_arn},
    )


async def get(hub, ctx, device_arn: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets the details of a device by device ARN.

    Args:
        device_arn(str, optional): The ARN of the device for which to request details. Required. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.device.init.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.device.init.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="get_device",
        op_kwargs={"DeviceArn": device_arn},
    )


async def search(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    filters: List = None,
    sort_criteria: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Searches devices and lists the ones that meet a set of filter criteria.

    Args:
        next_token(str, optional): An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response includes only results beyond the token, up to the value specified by MaxResults. Defaults to None.
        max_results(int, optional): The maximum number of results to include in the response. If more results exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved. Defaults to None.
        filters(List, optional): The filters to use to list a specified set of devices. Supported filter keys are DeviceName, DeviceStatus, DeviceStatusDetailCode, RoomName, DeviceType, DeviceSerialNumber, UnassociatedOnly, ConnectionStatus (ONLINE and OFFLINE), NetworkProfileName, NetworkProfileArn, Feature, and FailureCode. Defaults to None.
        sort_criteria(List, optional): The sort order to use in listing the specified set of devices. Supported sort keys are DeviceName, DeviceStatus, RoomName, DeviceType, DeviceSerialNumber, ConnectionStatus, NetworkProfileName, NetworkProfileArn, Feature, and FailureCode. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.device.init.search(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.device.init.search
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="search_devices",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "Filters": filters,
            "SortCriteria": sort_criteria,
        },
    )


async def update(hub, ctx, device_arn: str = None, device_name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates the device name by device ARN.

    Args:
        device_arn(str, optional): The ARN of the device to update. Required. Defaults to None.
        device_name(str, optional): The updated device name. Required. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.device.init.update(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.device.init.update
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="update_device",
        op_kwargs={"DeviceArn": device_arn, "DeviceName": device_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, assessment_report_id: str, assessment_id: str) -> Dict:
    r"""
    **Autogenerated function**

     Returns the URL of a specified assessment report in Audit Manager.

    Args:
        assessment_report_id(str):  The identifier for the assessment report. .
        assessment_id(str):  The identifier for the specified assessment. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.auditmanager.assessment.report.url.get(
                ctx, assessment_report_id=value, assessment_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.auditmanager.assessment.report.url.get assessment_report_id=value, assessment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="auditmanager",
        operation="get_assessment_report_url",
        op_kwargs={
            "assessmentReportId": assessment_report_id,
            "assessmentId": assessment_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, standards_subscription_requests: List) -> Dict:
    r"""
    **Autogenerated function**

    Enables the standards specified by the provided StandardsArn. To obtain the ARN for a standard, use the DescribeStandards operation. For more information, see the Security Standards section of the Security Hub User Guide.

    Args:
        standards_subscription_requests(List): The list of standards checks to enable.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.enable.standard.batch(
                ctx, standards_subscription_requests=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.enable.standard.batch standards_subscription_requests=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="batch_enable_standards",
        op_kwargs={"StandardsSubscriptionRequests": standards_subscription_requests},
    )
